# PyMediathek

Python library for [MediathekView](https://mediathekview.de/)

## Requirements

- Python >= 3.10
- aiohttp


## Install
```bash
pip install pymediathek
```

## Credits

Special thanks to the contributors of MediathekView and MediathekViewWeb. Without it, this library simply wouldn't exist.
